==> yaspot_0.2.1-2.tar.gz: yaspot-0.2.1/src/glue.h <==
#ifndef _FOO_GLUE_H_FOO_
#define _FOO_GLUE_H_FOO_

#include <hildon/hildon.h>

#include "audio.h"

struct yaspot_glue_t;
typedef struct yaspot_glue_t yaspot_glue_t;

struct yaspot_glue_response_t;
typedef struct yaspot_glue_response_t yaspot_glue_response_t;

typedef void (*yaspot_glue_state_changed_t)(gboolean playing, gboolean paused, gpointer data);
/* This trigger calls about once in a second. */
typedef void (*yaspot_glue_timer_update_t)(yaspot_glue_t *t, gint now, gint length, gpointer data);

void yaspot_glue_add_state_cb(yaspot_glue_t *t, yaspot_glue_state_changed_t callback, gpointer userdata);
void yaspot_glue_del_state_cb(yaspot_glue_t *t, yaspot_glue_state_changed_t callback, gpointer userdata);
/* When called with NULL callback, callback is reset. */
void yaspot_glue_set_timer_cb(yaspot_glue_t *t, yaspot_glue_timer_update_t callback, gpointer userdata);

yaspot_glue_t* yaspot_glue_init(DBusConnection *dbus);
int yaspot_glue_cleanup(yaspot_glue_t *t);

int yaspot_glue_auth(yaspot_glue_t *t, const gchar *username, const gchar *password, gint high_bitrate);
void yaspot_glue_print_info(yaspot_glue_t *t);

/* search & artist or album from playlist
 * returns GLUE_LIST type object
 * */
yaspot_glue_response_t* yaspot_glue_search(yaspot_glue_t *t, const gchar *search, gint maxresults);

/* get in num track artist response (start from 1)
 * return GLUE_ARTIST type object
 */
yaspot_glue_response_t* yaspot_glue_artist(yaspot_glue_response_t *r, gint num);
/* get max_chars length of current response artist description, -1 for full text,
 * return NULL if no description available */
gchar* yaspot_glue_artist_description(yaspot_glue_response_t *r, gint max_chars);
int yaspot_glue_artist_num_albums(yaspot_glue_response_t *r);
yaspot_glue_response_t* yaspot_glue_artist_album(yaspot_glue_response_t *r, gint num);
/* get in num track album response (start from 1)
 * return GLUE_ALBUM type object
 */
yaspot_glue_response_t* yaspot_glue_album(yaspot_glue_response_t *r, gint num);

gboolean yaspot_glue_album_from_artist(yaspot_glue_response_t *album, yaspot_glue_response_t *artist);
gboolean yaspot_glue_album_is_single(yaspot_glue_response_t *r, gint single_limit);
gboolean yaspot_glue_album_is_compilation(yaspot_glue_response_t *r, gint artist_limit);
int yaspot_glue_album_year(yaspot_glue_response_t *r);

gint yaspot_glue_res_n_tracks(yaspot_glue_response_t *r);

/* get all stored playlists
 * returns GLUE_PLAYLISTS type object
 */
yaspot_glue_response_t* yaspot_glue_stored_lists(yaspot_glue_t *t);

/* get nth playlist from list of playlists (start from 1)
 * returns GLUE_LIST type object
 */
yaspot_glue_response_t* yaspot_glue_stored_playlist(yaspot_glue_response_t *r, gint num);

//gchar* yaspot_glue_response_

/* save whatever response data to model data */
void yaspot_glue_response_to_model(yaspot_glue_response_t *r, GtkListStore *model);
void yaspot_glue_response_to_queue_model(yaspot_glue_response_t *r, GtkListStore *model);

/* get whatever "name" associated to response object.
 * caller must free received string
 */
gchar* yaspot_glue_response_get_name(yaspot_glue_response_t *r);

void* yaspot_glue_get_image(yaspot_glue_response_t *r, gint *len);

int yaspot_glue_response_ref(yaspot_glue_response_t *r);
int yaspot_glue_response_unref(yaspot_glue_response_t *r);

int yaspot_glue_play(yaspot_glue_response_t *r, gint num);
int yaspot_glue_res_stop(yaspot_glue_response_t* t);
int yaspot_glue_stop(yaspot_glue_t* t);
int yaspot_glue_set_pause(yaspot_glue_t *t, gboolean pause);
int yaspot_glue_next(yaspot_glue_t *t);
int yaspot_glue_prev(yaspot_glue_t *t);

/* returns currently active playing queue and references it bt 1.
 * caller should unref response object after use. */
yaspot_glue_response_t* yaspot_glue_current_queue(yaspot_glue_t *t);
yaspot_glue_response_t* yaspot_glue_res_current_queue(yaspot_glue_response_t *r);

gboolean yaspot_glue_playing(yaspot_glue_t *t);
gchar* yaspot_glue_current_track(yaspot_glue_t *t);

/* current active playlist track number, counting starts from 1 */
gint yaspot_glue_current_track_num(yaspot_glue_t *t);

#endif

// vim: expandtab shiftwidth=4

==> yaspot_0.3.0.tar.gz: yaspot-0.3.0/src/glue.h <==
#ifndef _FOO_GLUE_H_FOO_
#define _FOO_GLUE_H_FOO_

#include <hildon/hildon.h>

#include "audio.h"

struct yaspot_glue_t;
typedef struct yaspot_glue_t yaspot_glue_t;

struct yaspot_glue_response_internal_t;
typedef struct yaspot_glue_response_internal_t yaspot_glue_response_internal_t;

struct yaspot_glue_response_t {
    enum {
        GLUE_SEARCH,
        GLUE_LIST,
        GLUE_PLAYLISTS,
        GLUE_ARTIST,
        GLUE_ALBUM
    } type;

    yaspot_glue_response_internal_t *priv;
};
typedef struct yaspot_glue_response_t yaspot_glue_response_t;

enum yaspot_state_t {
    YASPOT_INITIALIZED = 0,
    YASPOT_CONNECTING,
    YASPOT_CONNECTED,
    YASPOT_AUTH_FAILED,
    YASPOT_DISCONNECTED,
    YASPOT_OFFLINE,
};
typedef enum yaspot_state_t yaspot_state_t;

enum yaspot_playback_state_t {
    YASPOT_NO_STATE             = 0x0000U,
    YASPOT_PLAYING              = 0x0001U,
    YASPOT_PAUSED               = 0x0002U,
    YASPOT_START_PLAYBACK       = 0x0004U,
    YASPOT_NEW_TRACK            = 0x0008U,
};
typedef enum yaspot_playback_state_t yaspot_playback_state_t;

struct yaspot_playlist_entry_t {
    gchar *name;
    gchar *author;
    gchar *id;
};
typedef struct yaspot_playlist_entry_t yaspot_playlist_entry_t;

typedef void (*yaspot_glue_response_cb)(yaspot_glue_t *t, gpointer response, gpointer userdata);

typedef void (*yaspot_glue_state_changed_t)(yaspot_state_t state, yaspot_playback_state_t pb_state, gpointer data);
/* This trigger calls about once in a second. */
typedef void (*yaspot_glue_timer_update_t)(yaspot_glue_t *t, gint now, gint length, gpointer data);

void yaspot_playlist_reload(yaspot_glue_t *t, yaspot_glue_response_cb cb, gpointer userdata);
gint yaspot_playlist_length(yaspot_glue_t *t);
const yaspot_playlist_entry_t* yaspot_playlist_iterate(yaspot_glue_t *t, void **state);

void yaspot_glue_add_state_cb(yaspot_glue_t *t, yaspot_glue_state_changed_t callback, gpointer userdata);
void yaspot_glue_del_state_cb(yaspot_glue_t *t, yaspot_glue_state_changed_t callback, gpointer userdata);
/* When called with NULL callback, callback is reset. */
void yaspot_glue_set_timer_cb(yaspot_glue_t *t, yaspot_glue_timer_update_t callback, gpointer userdata);

yaspot_glue_t* yaspot_glue_init(DBusConnection *dbus);
int yaspot_glue_cleanup(yaspot_glue_t *t);

void yaspot_glue_set_credentials(yaspot_glue_t *t, const gchar *username, const gchar *password);
void yaspot_glue_set_high_bitrate(yaspot_glue_t *t, gboolean high_bitrate);
gint yaspot_glue_connect(yaspot_glue_t *t);

void yaspot_glue_print_info(yaspot_glue_t *t);

/* search & artist or album from playlist
 * returns GLUE_LIST type object
 * */
yaspot_glue_response_t* yaspot_glue_search(yaspot_glue_t *t, const gchar *search, gint maxresults);

/* get in num track artist response (start from 1)
 * return GLUE_ARTIST type object
 */
yaspot_glue_response_t* yaspot_glue_artist(yaspot_glue_response_t *r, gint num);
yaspot_glue_response_t* yaspot_glue_artist_by_id(yaspot_glue_t *t, const gchar *id);

/* get max_chars length of current response artist description, -1 for full text,
 * return NULL if no description available */
gchar* yaspot_glue_artist_description(yaspot_glue_response_t *r, gint max_chars);
int yaspot_glue_artist_num_albums(yaspot_glue_response_t *r);
yaspot_glue_response_t* yaspot_glue_artist_album(yaspot_glue_response_t *r, gint num);
/* get in num track album response (start from 1)
 * return GLUE_ALBUM type object
 */
gboolean yaspot_glue_album(yaspot_glue_response_t *r, yaspot_glue_response_cb cb, gint num, gpointer userdata);
gboolean yaspot_glue_album_by_id(yaspot_glue_t *t, yaspot_glue_response_cb cb, const gchar *id, gpointer userdata);

gboolean yaspot_glue_album_from_artist(yaspot_glue_response_t *album, yaspot_glue_response_t *artist);
gboolean yaspot_glue_album_is_single(yaspot_glue_response_t *r, gint single_limit);
gboolean yaspot_glue_album_is_compilation(yaspot_glue_response_t *r, gint artist_limit);
int yaspot_glue_album_year(yaspot_glue_response_t *r);

gint yaspot_glue_res_n_tracks(yaspot_glue_response_t *r);

/* get nth playlist from list of playlists (start from 1)
 * returns GLUE_LIST type object
 */
yaspot_glue_response_t* yaspot_glue_stored_playlist(yaspot_glue_response_t *r, gint num);
gboolean yaspot_glue_stored_playlist_by_id(yaspot_glue_t *t, yaspot_glue_response_cb cb, const gchar *id, gpointer userdata);

//gchar* yaspot_glue_response_

/* save whatever response data to model data */
void yaspot_glue_response_to_model(yaspot_glue_response_t *r, GtkListStore *model);
void yaspot_glue_response_to_queue_model(yaspot_glue_response_t *r, GtkListStore *model);

/* get whatever "name" associated to response object.
 * caller must free received string
 */
gchar* yaspot_glue_response_get_name(yaspot_glue_response_t *r);

void* yaspot_glue_get_image(yaspot_glue_response_t *r, gint *len);

int yaspot_glue_response_ref(yaspot_glue_response_t *r);
int yaspot_glue_response_unref(yaspot_glue_response_t *r);

int yaspot_glue_play(yaspot_glue_response_t *r, guint num);
int yaspot_glue_res_stop(yaspot_glue_response_t* t);
int yaspot_glue_stop(yaspot_glue_t* t);
int yaspot_glue_set_pause(yaspot_glue_t *t, gboolean pause);
int yaspot_glue_next(yaspot_glue_t *t);
int yaspot_glue_prev(yaspot_glue_t *t);

/* returns currently active playing queue and references it bt 1.
 * caller should unref response object after use. */
yaspot_glue_response_t* yaspot_glue_current_queue(yaspot_glue_t *t);
yaspot_glue_response_t* yaspot_glue_res_current_queue(yaspot_glue_response_t *r);

gboolean yaspot_glue_playing(yaspot_glue_t *t);
gchar* yaspot_glue_current_track(yaspot_glue_t *t);

/* current active playlist track number, counting starts from 1 */
gint yaspot_glue_current_track_num(yaspot_glue_t *t);

/* return unique identifier for this type of response object */
const char* yaspot_glue_response_id(yaspot_glue_response_t *r);

#endif

// vim: expandtab shiftwidth=4
